=====================
 icemac.ab.importxls
=====================

This package enables `icemac.addressbook`_ to import XLS (Excel) files.

.. _`icemac.addressbook` : https://pypi.org/project/icemac.addressbook

Copyright (c) 2009-2018 Michael Howitz

This package is licensed under the MIT License, see LICENSE.txt inside the
package.

Hacking
=======

Source code
-----------

Get the source code::

   $ hg clone https://bitbucket.org/icemac/icemac.ab.importxls

or fork me on: https://bitbucket.org/icemac/icemac.ab.importxls

Running Tests
-------------

To run the tests yourself call::

  $ python2.7 bootstrap.py
  $ bin/buildout
  $ bin/py.test
